Discretizations
===============

Abstract interface
------------------

.. automodule:: meshmode.discretization

Element Groups for Composite Polynomial Discretization
------------------------------------------------------

.. automodule:: meshmode.discretization.poly_element

Visualization
-------------

.. automodule:: meshmode.discretization.visualization
